/*
 * Copyright 2011 Daniel Josefsson
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package se.dannej.fakehttpserver;

/**
 * A class representing a request header.
 */
public class Header {
	public static class Builder {
		private String name;
		private String value;
		
		public static Builder aHeader() {
			return new Builder();
		}

		public Builder withName(String name) {
			this.name = name;
			return this;
		}
		
		public Builder withValue(String value) {
			this.value = value;
			return this;
		}
		
		public Header build() {
			return new Header(this);
		}
	}
	
	private String name;
	private String value;
	
	private Header(Builder builder) {
		this.name = builder.name;
		this.value = builder.value;
	}
	
	public Header(String name, String value) {
		this.name = name;
		this.value = value;
	}

	public String getName() {
		return name;
	}
	
	public String getValue() {
		return value;
	}
}
