/*
 * Copyright 2011 Daniel Josefsson
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package se.dannej.fakehttpserver.expect;

import static se.dannej.fakehttpserver.expect.ExpectationState.createRequestExpectation;
import se.dannej.fakehttpserver.FakeHttpServer;
import se.dannej.fakehttpserver.expect.cardinality.Cardinalities;

/**
 * Abstract class used to add expectations of {@link FakeHttpServer}s.
 * Has traits from {@link org.jmock.integration.junit4.JMock}s {@link org.jmock.Expectations}.
 */
public abstract class Expectations {

	/**
	 * Set expectation to have exactly one matching request.
	 * @param server
	 * @return
	 */
	public static Requests oneOf(FakeHttpServer server) {
		return createRequestExpectation(server, Cardinalities.oneOf());
	}

	/**
	 * Set expectation to allow any number of matching requests.
	 * @param server
	 * @return
	 */
	public static Requests allowing(FakeHttpServer server) {
		return createRequestExpectation(server, Cardinalities.allowing());
	}

	/**
	 * Set expectation to not have any matching requests.
	 * @param server
	 * @return
	 */
	public static Requests never(FakeHttpServer server) {
		return createRequestExpectation(server, Cardinalities.never());
	}
	
	/**
	 * Set action to perform on a matching request.
	 * @param actions
	 */
	public static void will(ResponseAction... actions) {
		Requests currentRequest = ExpectationState.getCurrentRequest();
		if (currentRequest == null) {
			throw new IllegalExpectationStateException("must have an expectation (e.g. oneOf) before adding an action");
		}
		for (ResponseAction action : actions) {
			currentRequest.addAction(action);
		}
	}
}
