/*
 * Copyright 2011 Daniel Josefsson
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package se.dannej.fakehttpserver.expect.cardinality;

import org.hamcrest.Description;

import se.dannej.fakehttpserver.expect.Expectations;

/**
 * Convenience class for creating common {@link Cardinality}s. Used by {@link Expectations}.
 */
public class Cardinalities {
	/**
	 * @return an {@link Cardinality} object expecting exactly one matching request.
	 */
	public static Cardinality oneOf() {
		return new Cardinality() {
			private long invoked = 0;
			
			@Override
			public void invoked() {
				invoked++;
			}
			
			@Override
			public boolean isSatisfied() {
				return invoked == 1;
			}
			
			@Override
			public void describeTo(Description description) {
				description.appendText("exactly one (1) of ");
			}
		};
	}

	/**
	 * @return an {@link Cardinality} object expecting no matching requests.
	 */
	public static Cardinality never() {
		return new Cardinality() {
			boolean invoked = false;
			
			@Override
			public void invoked() {
				invoked = true;
			}
			
			@Override
			public boolean isSatisfied() {
				return !invoked;
			}
			
			@Override
			public void describeTo(Description description) {
				description.appendText("never ");
			}
		};
	}
	
	/**
	 * @return an {@link Cardinality} object allowing any number of matching requests.
	 */
	public static Cardinality allowing() {
		return new Cardinality() {
			@Override
			public void invoked() {
			}
			
			@Override
			public boolean isSatisfied() {
				return true;
			}
			
			@Override
			public void describeTo(Description description) {
			}
		};
	}
}
