/*
 * Copyright 2011 Daniel Josefsson
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package se.dannej.fakehttpserver.expect.matcher;

import org.hamcrest.Description;

import se.dannej.fakehttpserver.FakeHttpServletRequest;

/**
 * {@link RequestMatcher} that matches on the request method.
 */
public class MethodMatcher extends RequestMatcher {
	private final String method;

	private MethodMatcher(String methodName) {
		this.method = methodName;
	}
	
	@Override
	public boolean matchesSafely(FakeHttpServletRequest actualRequest) {
		return method.matches(actualRequest.getMethod());
	}

	@Override
	public void describeTo(Description paramDescription) {
		paramDescription.appendText("request method " + method);
	}
	
	public String getMethod() {
		return method;
	}
	
	public static MethodMatcher headMatcher(String methodName) {
		return new MethodMatcher(methodName);
	}
}
